/* ============================================================
 * File  : plugin_mykipi.cpp
 * Author: Andrei Borovsky <borovsky@tochka.ru>
 * Date  : 2006-07-10
 * Description :
 *
 * Copyright 2006 by Andrei Borovsky
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * ============================================================ */

// KDE includes.
  
#include <klocale.h>
#include <kaction.h>
#include <kgenericfactory.h>
#include <klibloader.h>
#include <kconfig.h>
#include <kdebug.h>
#include <kmessagebox.h>
#include <qstringlist.h>

// LibKIPi includes.

#include <libkipi/imagecollection.h>

// Local includes.

#include "plugin_mykipi.h"
#include <qstringlist.h>
// A macro from KDE KParts to export the symbols for this plugin and
// create the factory for it. The first argument is the name of the
// plugin library and the#include <kmessagebox.h> second is the genericfactory templated from
// the class for your plugin

typedef KGenericFactory<Plugin_MyKIPI> Factory;

K_EXPORT_COMPONENT_FACTORY( kipiplugin_mykipi,
                            Factory("kipiplugin_mykipi"));

Plugin_MyKIPI::Plugin_MyKIPI(QObject *parent,
                                     const char*,
                                     const QStringList&)
    : KIPI::Plugin( Factory::instance(), parent, "MyKIPI")
{
    kdDebug( 51001 ) << "Plugin_MyKIPI plugin loaded" << endl;
}

void Plugin_MyKIPI::setup( QWidget* widget )
{
    KIPI::Plugin::setup( widget );
    
    // this is our action shown in the menubar/toolbar of the mainwindow
    m_actionMyKIPI = new KAction (i18n("Sample KIPI Plugin..."),
                                   "misc",
                                   0,	// do never set shortcuts from plugins.
                                   this,
                                   SLOT(slotActivate()),
                                   actionCollection(),
                                   "mykipi");
    
    addAction( m_actionMyKIPI );

    m_interface = dynamic_cast< KIPI::Interface* >( parent() );
    
    if ( !m_interface ) 
           {
           kdError( 51000 ) << "Kipi interface is null!" << endl;
           return;
           }
}

void Plugin_MyKIPI::slotActivate()
{
    kdDebug( 51000 ) << "Plugin_MyKIPI slot activated" << endl;

    KIPI::ImageCollection selection = m_interface->currentSelection();
    
    if ( !selection.isValid() ) {
        kdDebug( 51000) << "No Selection!" << endl;
    }
    else {
        KURL::List images = selection.images();
        QStringList SL = images.toStringList();
        QString S = SL.join("\n");
        KMessageBox::information(0, S, "Selected Images");
    }
}

KIPI::Category Plugin_MyKIPI::category( KAction* action ) const
{
    if ( action == m_actionMyKIPI )
       return KIPI::IMAGESPLUGIN;
    
    kdWarning( 51000 ) << "Unrecognized action for plugin category identification" << endl;
    return KIPI::IMAGESPLUGIN; // no warning from compiler, please
}

#include "plugin_mykipi.moc"
